@@ -1,9 +1,18 @@
+r"""
+***************
+optimix package
+***************
+
+Abstract function optimisation.
+
+"""
+
 from pkg_resources import DistributionNotFound as _DistributionNotFound
 from pkg_resources import get_distribution as _get_distribution
 
-from .exception import OptimixError
 from . import testing
 from .check_grad import approx_fprime, check_grad
+from .exception import OptimixError
 from .function import Function, FunctionReduce
 from .optimize import maximize, maximize_scalar, minimize, minimize_scalar
 from .types import Matrix, Scalar, Vector
@@ -13,7 +22,14 @@ try:
 except _DistributionNotFound:
     __version__ = 'unknown'
 
+
 def test():
+    try:
+        import pytest_pep8
+    except ImportError:
+        print("Please, install pytest-pep8 in order to proceed.")
+        return 1
+
     import os
     p = __import__('optimix').__path__[0]
     src_path = os.path.abspath(p)
@@ -29,3 +45,10 @@ def test():
         print("Congratulations. All tests have passed!")
 
     return return_code
+
+
+__all__ = [
+    'testing', 'approx_fprime', 'check_grad', 'OptimixError', 'Function',
+    'FunctionReduce', 'maximize', 'maximize_scalar', 'minimize',
+    'minimize_scalar', 'Matrix', 'Scalar', 'Vector'
+]
