@@ -1,8 +1,8 @@
 from numpy.testing import assert_allclose
 
-from optimix.variables import merge_variables
-from optimix.variables import Variables
 from optimix import Scalar
+from optimix.variables import Variables, merge_variables
+
 
 def test_variables_set():
     a = Scalar(1.0)
@@ -15,11 +15,13 @@ def test_variables_set():
     v.set({'a': 0.5})
     assert_allclose(v.get('a'), 0.5)
 
+
 def test_variables_str():
     v = Variables(dict(a=Scalar(1.0), b=Scalar(1.5)))
     assert v.__str__() == """Variables(a=Scalar(1.0),
           b=Scalar(1.5))"""
 
+
 def test_variables_merge():
     a = Variables(a0=Scalar(1.0))
     b = Variables(b0=Scalar(1.0))
@@ -30,6 +32,7 @@ def test_variables_merge():
     assert a.get('a0').value == 2.0
     assert a.get('a0').value == c.get('a.a0').value
 
+
 def test_variables_setattr():
     a = Variables(a0=Scalar(1.0))
 
@@ -39,5 +42,6 @@ def test_variables_setattr():
     assert a.get('a0').value == 1.0
     assert a.get('a1').value == 3.0
 
+
 if __name__ == '__main__':
     __import__('pytest').main([__file__, '-s'])
